@@ -7,9 +7,9 @@ from typing import Final
 STATE_ON: Final = "on"
 STATE_OFF: Final = "off"
 
+ATTR_LOADED: Final = "loaded"
 ATTR_INDEX: Final = "index"
 ATTR_VALUE: Final = "value"
-ATTR_EXTRA: Final = "extra"
 ATTR_STATE: Final = "state"
 ATTR_SENSORS: Final = "sensors"
 ATTR_PASSWORD: Final = "password"
@@ -21,6 +21,8 @@ ATTR_TRANSMISSION: Final = "transmission"
 ATTR_THERMOSTAT: Final = "thermostat"
 ATTR_CURRENT_TEMP: Final = "current_temp"
 ATTR_TARGET_TEMP: Final = "target_temp"
+ATTR_DEVICE_INDEX: Final = "device_index"
+ATTR_OFFSET: Final = "offset"
 
 BYTE_UNDEFINED: Final = 0xFF
 
@@ -43,6 +45,20 @@ class DeviceState(IntEnum):
     OTHER = 11
 
 
+@unique
+class AlertType(IntEnum):
+    """Contains alert types."""
+
+    POWER_LOSS = 0
+    BOILER_TEMP_SENSOR_FAILURE = 1
+    MAX_BOILER_TEMP_EXCEEDED = 2
+    FEEDER_TEMP_SENSOR_FAILURE = 3
+    MAX_FEEDER_TEMP_EXCEEDED = 4
+    EXHAUST_TEMP_SENSOR_FAILURE = 5
+    KINDLING_FAILURE = 7
+    FAN_FAILURE = 11
+
+
 @unique
 class DeviceType(IntEnum):
     """Contains device addresses."""
