@@ -1,21 +1,21 @@
 """Contains device representations."""
 from __future__ import annotations
 
-from abc import ABC
 import asyncio
 from typing import ClassVar, Dict, List, Optional
 
 from pyplumio import util
-from pyplumio.const import DeviceType
+from pyplumio.const import DeviceType, FrameType
 from pyplumio.exceptions import ParameterNotFoundError, UnknownDeviceError
-from pyplumio.frames import Frame
+from pyplumio.frames import Frame, Request, get_frame_handler
+from pyplumio.helpers.factory import factory
 from pyplumio.helpers.parameter import Parameter
 from pyplumio.helpers.task_manager import TaskManager
 from pyplumio.helpers.typing import DeviceDataType, NumericType, SensorCallbackType
 
 
 def _handler_class_path(device_type_name: str) -> str:
-    """Return handler class path from device type name."""
+    """Return the handler class path for a given device type name."""
     device_type_name = util.to_camelcase(
         device_type_name, overrides={"ecomax": "EcoMAX", "ecoster": "EcoSTER"}
     )
@@ -31,57 +31,37 @@ DEVICE_TYPES: Dict[int, str] = {
 
 
 def get_device_handler(device_type: int) -> str:
-    """Return module and class for device type."""
+    """Return module and class for a given device type."""
     if device_type in DEVICE_TYPES:
         return "devices." + DEVICE_TYPES[device_type]
 
     raise UnknownDeviceError(f"Unknown device ({device_type})")
 
 
-class BaseDevice(ABC, TaskManager):
-    """Represents base device with awaitable properties."""
+class Device(TaskManager):
+    """Represents a device."""
 
+    queue: asyncio.Queue
     data: DeviceDataType
     _callbacks: Dict[str, List[SensorCallbackType]]
 
-    def __init__(self):
-        """Initializes Base Device object."""
+    def __init__(self, queue: asyncio.Queue):
+        """Initialize the device object."""
         super().__init__()
         self.data = {}
+        self.queue = queue
         self._callbacks = {}
 
     async def get_value(self, name: str, timeout: Optional[float] = None):
-        """Return a value. When encountering a parameter, only it's
-        value will be returned. To return the Parameter object use
-        get_parameter method."""
+        """Return a value. When used with parameter, only it's
+        value will be returned. To get the parameter object,
+        get_parameter() method must be used instead."""
         if name not in self.data:
             await asyncio.wait_for(self.create_event(name).wait(), timeout=timeout)
 
         value = self.data[name]
         return value.value if isinstance(value, Parameter) else value
 
-    async def set_value(
-        self,
-        name: str,
-        value: NumericType,
-        timeout: Optional[float] = None,
-        await_confirmation: bool = True,
-    ) -> bool:
-        """Set parameter value. Name should point
-        to a valid parameter object."""
-        if name not in self.data:
-            await asyncio.wait_for(self.create_event(name).wait(), timeout=timeout)
-
-        parameter = self.data[name]
-        if not isinstance(parameter, Parameter):
-            raise ParameterNotFoundError(f"Parameter not found ({name})")
-
-        if await_confirmation:
-            return await parameter.set(value)
-
-        self.create_task(parameter.set(value))
-        return True
-
     async def get_parameter(
         self, name: str, timeout: Optional[float] = None
     ) -> Parameter:
@@ -95,9 +75,50 @@ class BaseDevice(ABC, TaskManager):
 
         raise ParameterNotFoundError(f"Parameter not found ({name})")
 
-    def set_device_data(self, *args, **kwargs) -> None:
-        """Call registered callbacks on value change."""
-        self.create_task(self.async_set_device_data(*args, **kwargs))
+    async def set_value(
+        self,
+        name: str,
+        value: NumericType,
+        timeout: Optional[float] = None,
+        await_confirmation: bool = True,
+    ) -> bool:
+        """Set a parameter value. Name should point
+        to a valid parameter object, otherwise raises
+        ParameterNotFoundError."""
+        if name not in self.data:
+            await asyncio.wait_for(self.create_event(name).wait(), timeout=timeout)
+
+        parameter = self.data[name]
+        if not isinstance(parameter, Parameter):
+            raise ParameterNotFoundError(f"Parameter not found ({name})")
+
+        if await_confirmation:
+            return await parameter.set(value)
+
+        self.create_task(parameter.set(value))
+        return True
+
+    def subscribe(self, name: str, callback: SensorCallbackType) -> None:
+        """Subscribe a callback to the value change event."""
+        if name not in self._callbacks:
+            self._callbacks[name] = []
+
+        self._callbacks[name].append(callback)
+
+    def subscribe_once(self, name: str, callback: SensorCallbackType) -> None:
+        """Subscribe a callback to the single value change event."""
+
+        async def _callback(value):
+            """Unsubscribe the callback and call it."""
+            self.unsubscribe(name, _callback)
+            return await callback(value)
+
+        self.subscribe(name, _callback)
+
+    def unsubscribe(self, name: str, callback: SensorCallbackType) -> None:
+        """Usubscribe a callback from the value change event."""
+        if name in self._callbacks and callback in self._callbacks[name]:
+            self._callbacks[name].remove(callback)
 
     async def async_set_device_data(self, name: str, value) -> None:
         """Asynchronously call registered callbacks on value change."""
@@ -110,46 +131,20 @@ class BaseDevice(ABC, TaskManager):
         self.data[name] = value
         self.set_event(name)
 
+    def set_device_data(self, *args, **kwargs) -> None:
+        """Call registered callbacks on value change."""
+        self.create_task(self.async_set_device_data(*args, **kwargs))
+
     async def shutdown(self) -> None:
         """Cancel scheduled tasks."""
         self.cancel_tasks()
         await self.wait_until_done()
 
-    def subscribe(self, name: str, callback: SensorCallbackType) -> None:
-        """Register a callback for a value change."""
-        if name not in self._callbacks:
-            self._callbacks[name] = []
 
-        self._callbacks[name].append(callback)
-
-    def subscribe_once(self, name: str, callback: SensorCallbackType) -> None:
-        """Register a callback for a single call."""
-
-        async def _callback(value):
-            """Unregister the callback once it was called."""
-            try:
-                return await callback(value)
-            finally:
-                self.unsubscribe(name, _callback)
-
-        self.subscribe(name, _callback)
-
-    def unsubscribe(self, name: str, callback: SensorCallbackType) -> None:
-        """Remove the callback."""
-        if name in self._callbacks and callback in self._callbacks[name]:
-            self._callbacks[name].remove(callback)
-
-
-class Device(BaseDevice):
+class Addressable(Device):
     """Represents the addressable device."""
 
     address: ClassVar[int]
-    queue: asyncio.Queue
-
-    def __init__(self, queue: asyncio.Queue):
-        """Initialize new Device object."""
-        super().__init__()
-        self.queue = queue
 
     def handle_frame(self, frame: Frame) -> None:
         """Handle received frame."""
@@ -157,24 +152,45 @@ class Device(BaseDevice):
             for name, value in frame.data.items():
                 self.set_device_data(name, value)
 
+    async def make_request(
+        self,
+        name: str,
+        frame_type: FrameType,
+        retries: int = 3,
+        timeout: float = 5.0,
+    ):
+        """Send request for a data and wait for a value to become
+        available. If value is not available before timeout, retry
+        request."""
+        request: Request = factory(
+            get_frame_handler(frame_type), recipient=self.address
+        )
+        while retries > 0:
+            try:
+                self.queue.put_nowait(request)
+                return await self.get_value(name, timeout=timeout)
+            except asyncio.TimeoutError:
+                retries -= 1
 
-class Mixer(BaseDevice):
-    """Represents the mixer device."""
+        raise ValueError(f'could not request "{name}" with "{frame_type.name}"')
 
+
+class SubDevice(Device):
+    """Represents the sub-device."""
+
+    parent: Addressable
     index: int
 
-    def __init__(self, index: int = 0):
-        """Initialize new Mixer object."""
-        super().__init__()
+    def __init__(self, queue: asyncio.Queue, parent: Addressable, index: int = 0):
+        """Initialize a new sub-device object."""
+        super().__init__(queue)
+        self.parent = parent
         self.index = index
 
 
-class Thermostat(BaseDevice):
-    """Represent the thermostat device."""
+class Mixer(SubDevice):
+    """Represents the mixer sub-device."""
 
-    index: int
 
-    def __init__(self, index: int = 0):
-        """Initialize new Thermostat object."""
-        super().__init__()
-        self.index = index
+class Thermostat(SubDevice):
+    """Represent the thermostat sub-device."""
