@@ -5,8 +5,8 @@ import asyncio
 import logging
 from typing import Awaitable, Callable, Dict, Final, Optional, Tuple
 
-from pyplumio.const import DeviceType, FrameType
-from pyplumio.devices import Device, get_device_handler
+from pyplumio.const import ATTR_LOADED, DeviceType, FrameType
+from pyplumio.devices import Addressable, get_device_handler
 from pyplumio.exceptions import (
     FrameError,
     ReadError,
@@ -27,7 +27,6 @@ from pyplumio.structures.network_info import ATTR_NETWORK
 _LOGGER = logging.getLogger(__name__)
 
 CONSUMERS_NUMBER: Final = 2
-WRITE_DELAY: Final = 0.1
 
 
 def _get_device_handler_and_name(address: int) -> Tuple[str, str]:
@@ -42,7 +41,7 @@ class Protocol(TaskManager):
 
     writer: Optional[FrameWriter]
     reader: Optional[FrameReader]
-    devices: Dict[str, Device]
+    devices: Dict[str, Addressable]
     connected: asyncio.Event
     _network: NetworkInfo
     _queues: Tuple[asyncio.Queue, asyncio.Queue]
@@ -80,16 +79,20 @@ class Protocol(TaskManager):
         raise AttributeError
 
     async def frame_producer(
-        self, read_queue: asyncio.Queue, lock: asyncio.Lock
+        self, read_queue: asyncio.Queue, write_queue: asyncio.Queue
     ) -> None:
         """Handle frame reads."""
         await self.connected.wait()
         while self.connected.is_set():
-            await lock.acquire()
             try:
-                frame = await self.reader.read()
-                if frame is not None:
-                    read_queue.put_nowait(frame)
+                if write_queue.qsize() > 0:
+                    request = await write_queue.get()
+                    await self.writer.write(request)
+                    write_queue.task_done()
+
+                response = await self.reader.read()
+                if response is not None:
+                    read_queue.put_nowait(response)
             except UnknownFrameError as e:
                 _LOGGER.debug("Unknown frame type: %s", e)
             except ReadError as e:
@@ -101,26 +104,6 @@ class Protocol(TaskManager):
                 break
             except Exception as e:  # pylint: disable=broad-except
                 _LOGGER.exception(e)
-            finally:
-                lock.release()
-
-    async def write_consumer(
-        self, write_queue: asyncio.Queue, lock: asyncio.Lock
-    ) -> None:
-        """Handle frame writes."""
-        await self.connected.wait()
-        while self.connected.is_set():
-            frame = await write_queue.get()
-            await lock.acquire()
-            try:
-                await self.writer.write(frame)
-            except (OSError, asyncio.TimeoutError):
-                self.create_task(self.connection_lost())
-                break
-            finally:
-                write_queue.task_done()
-                lock.release()
-                await asyncio.sleep(WRITE_DELAY)
 
     async def frame_consumer(
         self, read_queue: asyncio.Queue, write_queue: asyncio.Queue
@@ -137,7 +120,8 @@ class Protocol(TaskManager):
                 continue
 
             if name not in self.devices:
-                device = factory(handler, queue=write_queue)
+                device: Addressable = factory(handler, queue=write_queue)
+                device.set_device_data(ATTR_LOADED, True)
                 self.devices[name] = device
                 self.set_event(name)
 
@@ -159,11 +143,9 @@ class Protocol(TaskManager):
         """Start consumers and producer tasks."""
         self.reader = FrameReader(reader)
         self.writer = FrameWriter(writer)
-        read_queue, write_queue = self.queues
+        write_queue = self.queues[1]
         write_queue.put_nowait(StartMasterRequest(recipient=DeviceType.ECOMAX))
-        lock: asyncio.Lock = asyncio.Lock()
-        self.create_task(self.write_consumer(write_queue, lock))
-        self.create_task(self.frame_producer(read_queue, lock))
+        self.create_task(self.frame_producer(*self.queues))
         for _ in range(CONSUMERS_NUMBER):
             self.create_task(self.frame_consumer(*self.queues))
 
@@ -187,7 +169,9 @@ class Protocol(TaskManager):
         if self.writer:
             await self.writer.close()
 
-    async def get_device(self, device: str, timeout: Optional[float] = None) -> Device:
+    async def get_device(
+        self, device: str, timeout: Optional[float] = None
+    ) -> Addressable:
         """Wait for device and return it once it's available."""
         if device not in self.devices:
             await asyncio.wait_for(self.create_event(device).wait(), timeout=timeout)
