@@ -2,12 +2,13 @@
 from __future__ import annotations
 
 import math
-from typing import Optional, Tuple
+from typing import Final, Optional, Tuple
 
 from pyplumio import util
-from pyplumio.const import ATTR_FUEL_CONSUMPTION
 from pyplumio.helpers.typing import DeviceDataType
-from pyplumio.structures import StructureDecoder
+from pyplumio.structures import StructureDecoder, ensure_device_data
+
+ATTR_FUEL_CONSUMPTION: Final = "fuel_consumption"
 
 
 class FuelConsumptionStructure(StructureDecoder):
@@ -18,7 +19,11 @@ class FuelConsumptionStructure(StructureDecoder):
     ) -> Tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
         fuel_consumption = util.unpack_float(message[offset : offset + 4])[0]
+        offset += 4
         if not math.isnan(fuel_consumption):
-            data[ATTR_FUEL_CONSUMPTION] = fuel_consumption
+            return (
+                ensure_device_data(data, {ATTR_FUEL_CONSUMPTION: fuel_consumption}),
+                offset,
+            )
 
-        return data, offset + 4
+        return ensure_device_data(data), offset
