@@ -1,11 +1,13 @@
 """Contains lambda structure decoder."""
 from __future__ import annotations
 
-from typing import Optional, Tuple
+from typing import Final, Optional, Tuple
 
-from pyplumio.const import ATTR_LOAD, BYTE_UNDEFINED
+from pyplumio.const import BYTE_UNDEFINED
 from pyplumio.helpers.typing import DeviceDataType
-from pyplumio.structures import StructureDecoder
+from pyplumio.structures import StructureDecoder, ensure_device_data
+
+ATTR_LOAD: Final = "load"
 
 
 class LoadStructure(StructureDecoder):
@@ -15,7 +17,7 @@ class LoadStructure(StructureDecoder):
         self, message: bytearray, offset: int = 0, data: Optional[DeviceDataType] = None
     ) -> Tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
-        if message[offset] != BYTE_UNDEFINED:
-            data[ATTR_LOAD] = message[offset]
+        if message[offset] == BYTE_UNDEFINED:
+            return ensure_device_data(data), offset + 1
 
-        return data, offset + 1
+        return ensure_device_data(data, {ATTR_LOAD: message[offset]}), offset + 1
